@@ -36,9 +36,9 @@ import android.content.ServiceConnection;
 import android.content.SharedPreferences;
 import android.graphics.Bitmap;
 import android.graphics.BitmapFactory;
-import android.media.audiofx.AudioEffect;
 import android.media.AudioManager;
 import android.media.AudioManager.OnAudioFocusChangeListener;
+import android.media.audiofx.AudioEffect;
 import android.net.Uri;
 import android.os.Binder;
 import android.os.Build;
@@ -90,7 +90,6 @@ import org.videolan.vlc.util.AndroidDevices;
 import org.videolan.vlc.util.Constants;
 import org.videolan.vlc.util.Permissions;
 import org.videolan.vlc.util.Util;
-import org.videolan.vlc.util.VLCInstance;
 import org.videolan.vlc.util.VLCOptions;
 import org.videolan.vlc.util.VoiceSearchParams;
 import org.videolan.vlc.util.WeakHandler;
@@ -114,7 +113,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
     private static final int SHOW_PROGRESS = 0;
     private static final int SHOW_TOAST = 1;
     private static final int END_MEDIASESSION = 2;
-    private static final int PUBLISH_STATE = 3;
+    private static final int PUBLISH_PROGRESS = 3;
 
     private static final long DELAY_DOUBLE_CLICK = 800L;
     private static final long DELAY_LONG_CLICK = 1000L;
@@ -177,10 +176,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
         super.onCreate();
         mSettings = PreferenceManager.getDefaultSharedPreferences(this);
         playlistManager = new PlaylistManager(this);
-        if (!VLCInstance.testCompatibleCPU(this)) {
-            stopSelf();
-            return;
-        }
+        Util.checkCpuCompatibility(this);
 
         mMedialibrary = VLCApplication.getMLInstance();
         if (!mMedialibrary.isInitiated()) registerMedialibrary(null);
@@ -551,8 +547,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
                 case MediaPlayer.Event.TimeChanged:
                     break;
                 case MediaPlayer.Event.PositionChanged:
-                    updateWidgetPosition(event.getPositionChanged());
-                    mHandler.sendEmptyMessage(PUBLISH_STATE);
+                    if (mWidget != 0) mHandler.obtainMessage(PUBLISH_PROGRESS, event.getPositionChanged());
                     break;
                 case MediaPlayer.Event.Vout:
                     break;
@@ -646,10 +641,10 @@ public class PlaybackService extends MediaBrowserServiceCompat{
                 case END_MEDIASESSION:
                     if (service.mMediaSession != null) service.mMediaSession.setActive(false);
                     break;
-                case PUBLISH_STATE:
+                case PUBLISH_PROGRESS:
                     final long time = System.currentTimeMillis();
                     if (time - lastPublicationDate > 1000L) {
-                        service.publishState();
+                        service.updateWidgetPosition((Float) msg.obj);
                         lastPublicationDate = time;
                     }
                     break;
